package com.yanzuoguang.util.vo;

import io.swagger.annotations.ApiModelProperty;

/**
 * 分页实现对象
 *
 * @author 颜佐光
 */
public class PageSizeReqVo extends BaseVo implements PageSizeReq {

    private static final long serialVersionUID = -3933114440447495323L;
    /**
     * 当前第几页
     */
    @ApiModelProperty(value = "第几页", required = true, example = "1", notes = "要查询第几页")
    private int pageIndex = 1;

    /**
     * 当前页面所包含的记录数量
     */
    @ApiModelProperty(value = "每页多少条", required = true, example = "20", notes = "每页包含多少条数据")
    private int pageSize = 20;

    /**
     * 构造函数
     */
    public PageSizeReqVo() {
        this(1, 20);
    }

    /**
     * 构造函数
     *
     * @param pageIndex 第几页
     * @param pageSize  每页大小
     */
    public PageSizeReqVo(int pageIndex, int pageSize) {
        this.pageIndex = pageIndex;
        this.pageSize = pageSize;
    }

    /**
     * 获取记录开始的编号
     *
     * @return 返回记录开始的编号
     */
    @Override
    @ApiModelProperty(value = "当前页的第一条序号", required = true, example = "1", hidden = true)
    public int getPageStart() {
        int pageIndex = this.pageIndex > 0 ? this.pageIndex : 1;
        return (pageIndex - 1) * this.pageSize;
    }

    /**
     * 获取记录结束的编号
     *
     * @return 返回记录结束的编号
     */
    @Override
    @ApiModelProperty(value = "当前页的最后一条序号", required = true, example = "20", hidden = true)
    public int getPageEnd() {
        int pageIndex = this.pageIndex > 0 ? this.pageIndex : 1;
        return pageIndex * this.pageSize;
    }

    @Override
    public int getPageIndex() {
        return pageIndex;
    }

    @Override
    public PageSizeReqVo setPageIndex(int pageIndex) {
        this.pageIndex = pageIndex;
        return this;
    }

    @Override
    public int getPageSize() {
        return pageSize;
    }

    @Override
    public PageSizeReqVo setPageSize(int pageSize) {
        this.pageSize = pageSize;
        return this;
    }
}
